<?php
define('ADMIN_PAGE_TITLE', 'Dashboard');
include_once('_local_auth.inc.php');
include_once('_header.inc.php');

// load stats
$totalActiveUrls     = (int) $db->getValue("SELECT COUNT(id) AS total FROM shorturl WHERE status = 'active'");
$totalDisabledUrls     = (int) $db->getValue("SELECT COUNT(id) AS total FROM shorturl WHERE status != 'active'");
$totalVisits       = (int) $db->getValue("SELECT SUM(visits) AS total FROM shorturl");
$totalRegisteredUsers = (int) $db->getValue("SELECT COUNT(id) AS total FROM users WHERE status='active'");
$newUsers30Days     = (int) $db->getValue("SELECT COUNT(id) AS total FROM users WHERE datecreated BETWEEN CURDATE() - INTERVAL 30 DAY AND CURDATE()");
$newUrls30Days       = (int) $db->getValue("SELECT COUNT(id) AS total FROM shorturl WHERE dateCreated BETWEEN CURDATE() - INTERVAL 30 DAY AND CURDATE()");
?>

<div class="row clearfix">
    <div class="col_12">
        <div class="sectionLargeIcon largeDashboardIcon"></div>
        <div class="widget clearfix">
            <h2><?php echo adminFunctions::t('quick_overview', 'Quick Overview'); ?></h2>
            <div class="widget_inside">
                <h3>Current Statistics</h3>
                <div class="report">
                    <a href="shorturl_manage.php">
                        <div class="button up">
                            <span class="value"><?php echo number_format($totalActiveUrls, 0); ?></span>
                            <span class="attr">Active Urls</span>
                        </div>
                    </a>

                    <a href="shorturl_manage.php">
                        <div class="button up">
                            <span class="value"><?php echo number_format($totalDisabledUrls, 0); ?></span>
                            <span class="attr">Disabled Urls</span>
                        </div>
                    </a>

                    <a href="shorturl_manage.php">
                        <div class="button up">
                            <span class="value"><?php echo number_format($totalVisits, 0); ?></span>
                            <span class="attr">Total Visits (All Urls)</span>
                        </div>
                    </a>
                    
                    <a href="shorturl_manage.php">
                        <div class="button up">
                            <span class="value"><?php echo number_format($newUrls30Days, 0); ?></span>
                            <span class="attr">New Urls (30 Days)</span>
                        </div>
                    </a>

                    <a href="user_manage.php?filterByAccountStatus=active">
                        <div class="button up">
                            <span class="value"><?php echo number_format($totalRegisteredUsers, 0); ?></span>
                            <span class="attr">Total Active Users</span>
                        </div>
                    </a>

                    <a href="user_manage.php">
                        <div class="button up">
                            <span class="value"><?php echo number_format($newUsers30Days, 0); ?></span>
                            <span class="attr">New Users (30 Days)</span>
                        </div>
                    </a>
                </div>
            </div>
        </div>
    </div>
</div>

<?php
// last 14 days chart
$tracker              = 14;
$last14Days           = array();
while ($tracker >= 0)
{
    $date              = date("Y-m-d", strtotime("-" . $tracker . " day"));
    $last14Days[$date] = 0;
    $tracker--;
}

$data = $db->getRows("SELECT COUNT(id) AS total, MID(dateCreated, 1, 10) AS dateItem FROM shorturl WHERE dateCreated >= '".date("Y-m-d H:i:s", strtotime("-14 days"))."' GROUP BY MID(dateCreated, 1, 10)");
$dataArr = array();
foreach($data AS $dataItem)
{
    $dataArr[$dataItem{'dateItem'}] = $dataItem['total'];
}

$tracker = 1;
$data    = array();
$label = array();
foreach ($last14Days AS $k => $total)
{
    $totalFiles = 0;
    if(isset($dataArr[$k]))
    {
        $totalFiles = $dataArr[$k];
    }
    $data[]     = '[' . $tracker . ',' . (int) $totalFiles . ']';
    $label[]    = '[' . $tracker . ',\'' . date('jS', strtotime($k)) . '\']';
    $tracker++;
}
?>

<div class="row clearfix">
    <div class="col_8">
        <div class="widget clearfix">
            <h2><?php echo adminFunctions::t("dashboard_graph_last_14_days_title", "New Urls (last 14 days)"); ?></h2>
            <div class="widget_inside">
                <div id="14_day_chart" style="width:100%; height:300px;" class="centered"></div>
                <script type="text/javascript">
                    $(function () {
                        var css_id = "#14_day_chart";
                        var data = [
                            {label: '<?php echo UCWords(adminFunctions::t("urls", "urls")); ?>', data: [<?php echo implode(", ", $data); ?>]}
                        ];
                        var options = {
                            series: {stack: 0,
                                lines: {show: false, steps: false },
                                grid: {backgroundColor: { colors: ["#fff", "#eee"] } },
                                bars: {show: true, barWidth: 0.9, align: 'center' } },
                            xaxis: {ticks: [<?php echo implode(", ", $label); ?>]},
                            colors: [ "#55A9D3" ]
                        };

                        $.plot($(css_id), data, options);
                    });
                </script>
            </div>
        </div>
    </div>

    <?php
    // pie chart of the status of items
    $data       = array();
    $dataForPie = $db->getRows("SELECT COUNT(shorturl.id) AS total, status FROM shorturl GROUP BY shorturl.status");
    foreach ($dataForPie AS $dataRow)
    {
        $data[]     = '{ label: "' . UCWords(adminFunctions::t($dataRow['status'], $dataRow['status'])) . '",  data: ' . (int) $dataRow['total'] . '}';
    }
    ?>
    <div class="col_4 last">
        <div class="widget">
            <h2><?php echo adminFunctions::t('url_status', 'Url Status'); ?></h2>
            <div class="widget_inside">
                <div id="url_status_chart" style="width:100%; height: 300px" class="centered"></div>
                <div id="url_status_chart_hover" class="pieHoverText"></div>
                <script type="text/javascript">
                    $(function () {
                        // data
                        var data = [
<?php echo implode(', ', $data); ?>
        ];

        // INTERACTIVE
        $.plot($("#url_status_chart"), data,
        {
            series: {
                pie: {
                    show: true
                }
            },
            grid: {
                hoverable: true,
                clickable: true
            },
            legend: {
                show: true
            }
        });
        $("#url_status_chart").bind("plothover", urlStatusChartHover);

    });

    function urlStatusChartHover(event, pos, obj)
    {
        if (!obj)
            return;
        percent = parseFloat(obj.series.percent).toFixed(2);
        $("#url_status_chart_hover").html('<span style="font-weight: bold; color: '+obj.series.color+'">'+obj.series.label+' ('+percent+'%)</span>');
    }
                </script>
            </div>
        </div>
    </div>
</div>


<?php
// last 12 months urls
$tracker    = 12;
$last12Months = array();
while ($tracker >= 0)
{
    $date              = date("Y-m", strtotime("-" . $tracker . " month"));
    $last12Months[$date] = 0;
    $tracker--;
}

$data = $db->getRows("SELECT COUNT(id) AS total, MID(dateCreated, 1, 7) AS dateItem FROM shorturl WHERE dateCreated >= '".date("Y-m-d H:i:s", strtotime("-12 months"))."' GROUP BY MID(dateCreated, 1, 7)");
$dataArr = array();
foreach($data AS $dataItem)
{
    $dataArr[$dataItem{'dateItem'}] = $dataItem['total'];
}

$tracker = 1;
$data    = array();
$label = array();
foreach ($last12Months AS $k => $total)
{
    $totalUrls = 0;
    if(isset($dataArr[$k]))
    {
        $totalUrls = $dataArr[$k];
    }
    $data[]     = '[' . $tracker . ',' . (int) $totalUrls . ']';
    $label[]    = '[' . $tracker . ',\'' . date('M y', strtotime($k)) . '\']';
    $tracker++;
}
?>

<div class="row clearfix">
    <div class="col_8">
        <div class="widget clearfix">
            <h2><?php echo adminFunctions::t("dashboard_graph_last_12_months_title", "New Urls (last 12 months)"); ?></h2>
            <div class="widget_inside">
                <div id="12_months_chart" style="width:100%; height:300px;" class="centered"></div>
                <script type="text/javascript">
                    $(function () {
                        var css_id = "#12_months_chart";
                        var data = [
                            {label: '<?php echo UCWords(adminFunctions::t("urls", "urls")); ?>', data: [<?php echo implode(", ", $data); ?>]}
                        ];
                        var options = {
                            series: {stack: 0,
                                lines: {show: false, steps: false },
                                grid: {backgroundColor: { colors: ["#fff", "#eee"] } },
                                bars: {show: true, barWidth: 0.9, align: 'center' } },
                            xaxis: {ticks: [<?php echo implode(", ", $label); ?>]},
                            colors: [ "#55A9D3" ]
                        };

                        $.plot($(css_id), data, options);
                    });
                </script>
            </div>
        </div>
    </div>

    <?php
    // pie chart of top 10 urls
    $data       = array();
    $dataForPie = $db->getRows("SELECT COUNT(id) AS total, shortUrl FROM shorturl WHERE status='active' GROUP BY shortUrl ORDER BY visits DESC LIMIT 10");
    $counter = 1;
    if(COUNT($dataForPie))
    {
        foreach ($dataForPie AS $dataRow)
        {
            if($counter > 10)
            {
                $otherTotal = $otherTotal+$dataRow['total'];
            }
            else
            {
                $data[] = '{ label: "' . strtolower($dataRow['shortUrl']) . '",  data: ' . (int) $dataRow['total'] . '}';
            }
            $counter++;
        }
    }
    ?>
    <div class="col_4 last">
        <div class="widget">
            <h2><?php echo adminFunctions::t('top_10_urls', 'Top 10 Urls'); ?></h2>
            <div class="widget_inside">
                <div id="url_type_chart" style="width:100%; height: 300px" class="centered"></div>
                <div id="url_type_chart_hover" class="pieHoverText"></div>
                <script type="text/javascript">
                    $(function () {
                        // data
                        var data = [
<?php echo implode(', ', $data); ?>
        ];

        // INTERACTIVE
        $.plot($("#url_type_chart"), data,
        {
            series: {
                pie: {
                    show: true
                }
            },
            grid: {
                hoverable: true,
                clickable: true
            },
            legend: {
                show: false
            }
        });
        $("#url_type_chart").bind("plothover", urlTypeChartHover);

    });

    function urlTypeChartHover(event, pos, obj)
    {
        if (!obj)
            return;
        percent = parseFloat(obj.series.percent).toFixed(2);
        $("#url_type_chart_hover").html('<span style="font-weight: bold; color: '+obj.series.color+'">'+obj.series.label+' ('+percent+'%)</span>');
    }
                </script>
            </div>
        </div>
    </div>
</div>


<?php
// last 14 days user registrations
$tracker    = 14;
$last14Days = array();
while ($tracker >= 0)
{
    $date              = date("Y-m-d", strtotime("-" . $tracker . " day"));
    $last14Days[$date] = 0;
    $tracker--;
}

$data = $db->getRows("SELECT COUNT(id) AS total, MID(datecreated, 1, 10) AS dateItem FROM users WHERE datecreated >= '".date("Y-m-d H:i:s", strtotime("-14 days"))."' GROUP BY MID(datecreated, 1, 10)");
$dataArr = array();
foreach($data AS $dataItem)
{
    $dataArr[$dataItem{'dateItem'}] = $dataItem['total'];
}

$tracker  = 1;
$dataFree = array();
$dataPaid = array();
$label = array();
foreach ($last14Days AS $k => $total)
{
    $totalUsers = 0;
    if(isset($dataArr[$k]))
    {
        $totalUsers = $dataArr[$k];
    }
    $dataFree[] = '[' . $tracker . ',' . (int) $totalUsers . ']';
    $label[]    = '[' . $tracker . ',\'' . date('jS', strtotime($k)) . '\']';
    $tracker++;
}
?>

<div class="row clearfix">
    <div class="col_8">
        <div class="widget clearfix">
            <h2><?php echo adminFunctions::t("dashboard_graph_user_registrations_title", "New Users (last 14 days)"); ?></h2>
            <div class="widget_inside">
                <div id="14_day_users" style="width:100%; height:300px;" class="centered"></div>
                <script type="text/javascript">
                    $(function () {
                        var css_id = "#14_day_users";
                        var data = [
                            {label: '<?php echo UCWords(adminFunctions::t("user", "user")); ?>', data: [<?php echo implode(", ", $dataFree); ?>]}
                        ];
                        var options = {
                            series: {stack: 0,
                                lines: {show: false, steps: false },
                                grid: {backgroundColor: { colors: ["#fff", "#eee"] } },
                                bars: {show: true, barWidth: 0.9, align: 'center' } },
                            xaxis: {ticks: [<?php echo implode(", ", $label); ?>]},
                            colors: [ "#55A9D3", "#4DA74D" ]
                        };

                        $.plot($(css_id), data, options);
                    });
                </script>
            </div>
        </div>
    </div>
</div>

<?php
include_once('_footer.inc.php');
?>